==> core-react-0.8.0.tgz: package/es/Tabs/Tabs.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';

var Tabs = /*#__PURE__*/function (_React$Component) {
  _inherits(Tabs, _React$Component);

  function Tabs(props) {
    var _this;

    _classCallCheck(this, Tabs);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tabs).call(this));

    _defineProperty(_assertThisInitialized(_this), "changeActiveIndex", function (activeIndex) {
      _this.setState({
        activeIndex: activeIndex
      });
    });

    _this.state = {
      activeIndex: props.activeIndex || 0
    };
    return _this;
  }

  _createClass(Tabs, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        tabs: this
      };
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'activeIndex' in nextProps && this.setState({
        activeIndex: nextProps.activeIndex || 0
      });
    }
  }, {
    key: "componentWillUpdate",
    value: function componentWillUpdate() {
      this.isInit = false;
      this.tabCount = this.panelCount = 0;
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.isInit = true;
      this.tabCount = this.panelCount = 0;
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          activeIndex = _this$props.activeIndex,
          activeKey = _this$props.activeKey,
          onChange = _this$props.onChange,
          onClose = _this$props.onClose,
          other = _objectWithoutProperties(_this$props, ["children", "className", "activeIndex", "activeKey", "onChange", "onClose"]);

      return React.createElement("div", _extends({
        className: cx("".concat("waui", "-tabs"), className)
      }, other), children);
    }
  }]);

  return Tabs;
}(React.Component);

Tabs.childContextTypes = {
  tabs: PropTypes.instanceOf(Tabs)
};
Tabs.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** Specifies which Tab is active */
  activeIndex: PropTypes.number,

  /** Tabs manage active state by default by index, but you can also bind `id` to each Tab and TabPanel */
  activeKey: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** The callback of switching Tab, param: (index, key) */
  onChange: PropTypes.func,

  /** The event of closing tab, param: (index, key) */
  onClose: PropTypes.func,
  customProp: function customProp(props) {
    if (('activeIndex' in props || 'activeKey' in props) && !props.onChange) {
      return new Error('You provided `activeIndex` or `activeKey` prop without an `onChange` handler');
    }

    if ('activeIndex' in props && 'activeKey' in props) {
      return new Error("`activeIndex` and `activeKey` can't exist at the same time");
    }
  }
};
export default Tabs;

==> core-react-0.8.2.tgz: package/es/Tabs/Tabs.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import PropTypes from 'prop-types';
import React from 'react';

var Tabs = /*#__PURE__*/function (_React$Component) {
  _inherits(Tabs, _React$Component);

  function Tabs(props) {
    var _this;

    _classCallCheck(this, Tabs);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tabs).call(this));

    _defineProperty(_assertThisInitialized(_this), "changeActiveIndex", function (activeIndex) {
      _this.setState({
        activeIndex: activeIndex
      });
    });

    _this.state = {
      activeIndex: props.activeIndex || 0
    };
    return _this;
  }

  _createClass(Tabs, [{
    key: "getChildContext",
    value: function getChildContext() {
      return {
        tabs: this
      };
    }
  }, {
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      'activeIndex' in nextProps && this.setState({
        activeIndex: nextProps.activeIndex || 0
      });
    }
  }, {
    key: "componentWillUpdate",
    value: function componentWillUpdate() {
      this.isInit = false;
      this.tabCount = this.panelCount = 0;
    }
  }, {
    key: "componentWillMount",
    value: function componentWillMount() {
      this.isInit = true;
      this.tabCount = this.panelCount = 0;
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          children = _this$props.children,
          className = _this$props.className,
          activeIndex = _this$props.activeIndex,
          activeKey = _this$props.activeKey,
          onChange = _this$props.onChange,
          onClose = _this$props.onClose,
          other = _objectWithoutProperties(_this$props, ["children", "className", "activeIndex", "activeKey", "onChange", "onClose"]);

      return (/*#__PURE__*/React.createElement("div", _extends({
          className: cx("".concat("waui", "-tabs"), className)
        }, other), children)
      );
    }
  }]);

  return Tabs;
}(React.Component);

Tabs.childContextTypes = {
  tabs: PropTypes.instanceOf(Tabs)
};
Tabs.propTypes = {
  children: PropTypes.any,
  className: PropTypes.string,

  /** Specifies which Tab is active */
  activeIndex: PropTypes.number,

  /** Tabs manage active state by default by index, but you can also bind `id` to each Tab and TabPanel */
  activeKey: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** The callback of switching Tab, param: (index, key) */
  onChange: PropTypes.func,

  /** The event of closing tab, param: (index, key) */
  onClose: PropTypes.func,
  customProp: function customProp(props) {
    if (('activeIndex' in props || 'activeKey' in props) && !props.onChange) {
      return new Error('You provided `activeIndex` or `activeKey` prop without an `onChange` handler');
    }

    if ('activeIndex' in props && 'activeKey' in props) {
      return new Error("`activeIndex` and `activeKey` can't exist at the same time");
    }
  }
};
export default Tabs;
